@@ -6,6 +6,7 @@
 
 # TODO - expand this
 
+
 class PyCUIOutOfBoundsError(Exception):
     """Error for when widget or text goes off of the py_cui grid
     """
@@ -32,3 +33,10 @@ class PyCUIMissingChildError(Exception):
     """
 
     pass
+
+
+class PyCUIInvalidValue(Exception):
+    """Error when a values passed is not valid or doeas not match requirements
+    """
+
+    pass
