@@ -41,9 +41,11 @@ class Popup(py_cui.ui.UIElement):
         self._text         = text
         self._selected     = True
         self._close_keys   = [py_cui.keys.KEY_ESCAPE]
-        self._color = color
-        self._border_color = color
-        self._selected_color = color
+        # Default to use the selected color for all aspects of ui element
+        self._color                 = color
+        self._border_color          = color
+        self._focus_border_color    = color
+        self._selected_color        = color
         self.update_height_width()
 
     
@@ -113,7 +115,6 @@ class Popup(py_cui.ui.UIElement):
         Can be implemented by subclass. Base draw function will draw the title and text in a bordered box
         """
 
-        super()._draw()
         target_y = int(self._stop_y - self._start_y / 2)
         self._renderer.set_color_rules([])
         self._renderer._set_bold()
@@ -190,7 +191,7 @@ class YesNoPopup(Popup):
             if self._command is not None:
                 self._command(ret_val)
             else:
-                self._root.show_warning_popup('No Command Specified', 'The Yes/No popup had no specified command')
+                self._root.show_warning_popup('No Command Specified', 'The textbox popup had no specified command!')
 
 
     def _draw(self):
