@@ -37,6 +37,10 @@ class UIElement:
         absolute dimensions of ui element in terminal characters
     _color : int
         Default color for which to draw element
+    _border_color: int
+        Color used to draw the border of the element when not focused
+    _focus_border_color: int
+        Color used to draw the border of the element when focused
     _selected : bool
         toggle for marking an element as selected
     _renderer : py_cui.renderer.Renderer
@@ -58,8 +62,10 @@ class UIElement:
         self._start_x,  self._stop_y    = 0, 0
         self._stop_x,   self._start_y   = 0, 0
         self._height,   self._width     = 0, 0
+        # Default UI Element color is white on black.
         self._color                     = py_cui.WHITE_ON_BLACK
         self._border_color              = self._color
+        self._focus_border_color        = self._color
         self._selected_color            = self._color
         self._mouse_press_handler       = None
         self._selected                  = False
@@ -72,14 +78,14 @@ class UIElement:
         """Must be implemented by subclass, computes the absolute coords of upper-left corner
         """
 
-        return 0, 0
+        raise NotImplementedError
 
 
     def get_absolute_stop_pos(self):
         """Must be implemented by subclass, computes the absolute coords of bottom-right corner
         """
 
-        return 1, 1
+        raise NotImplementedError
 
 
     def get_absolute_dimensions(self):
@@ -199,7 +205,10 @@ class UIElement:
             color code for combination
         """
 
-        return self._border_color
+        if self._selected:
+            return self._focus_border_color
+        else:
+            return self._border_color
 
 
     def get_selected_color(self):
@@ -273,6 +282,8 @@ class UIElement:
 
         if self._border_color == self._color:
             self._border_color = color
+        if self._focus_border_color == self._color:
+            self._focus_border_color = color
         if self._selected_color == self._color:
             self._selected_color = color
         self._color = color
@@ -290,6 +301,19 @@ class UIElement:
         self._border_color = color
 
 
+    def set_focus_border_color(self, color):
+        """Sets element border color if the current element
+        is focused
+
+        Parameters
+        ----------
+        color : int
+            New color pair key code
+        """
+
+        self._focus_border_color = color
+
+
     def set_selected_color(self, color):
         """Sets element sected color
 
@@ -342,7 +366,7 @@ class UIElement:
         """Must be implemented by subclass. Used to handle keypresses
         """
 
-        pass
+        raise NotImplementedError
 
 
     def add_mouse_press_handler(self, mouse_press_handler_func):
@@ -374,7 +398,7 @@ class UIElement:
         """Must be implemented by subclasses. Uses renderer to draw element to terminal
         """
 
-        pass
+        raise NotImplementedError
 
 
     def _assign_renderer(self, renderer):
@@ -422,7 +446,6 @@ class UIElement:
         return within_x and within_y
 
 
-
 class UIImplementation:
     """Base class for ui implementations.
 
@@ -694,7 +717,7 @@ class MenuImplementation(UIImplementation):
         return self._selected_item
 
 
-    def set_selected_item_index(self, selected_item):
+    def set_selected_item_index(self, selected_item_index):
         """Sets the currently selected item
 
         Parameters
@@ -703,7 +726,7 @@ class MenuImplementation(UIImplementation):
             The new selected item index
         """
 
-        self._selected_item = selected_item
+        self._selected_item = selected_item_index
 
 
     def _scroll_up(self):
@@ -799,7 +822,7 @@ class MenuImplementation(UIImplementation):
 
         Parameters
         ----------
-        item_list : list of Object
+        item_list : List[Object]
             list of objects to add as items to the scrollmenu
         """
 
@@ -843,7 +866,7 @@ class MenuImplementation(UIImplementation):
 
         Returns
         -------
-        item_list : list of str
+        item_list : List[Object]
             list of items in the scrollmenu
         """
 
@@ -855,7 +878,7 @@ class MenuImplementation(UIImplementation):
 
         Returns
         -------
-        item : str
+        item : Object
             selected item, or None if there are no items in the menu
         """
 
@@ -864,6 +887,19 @@ class MenuImplementation(UIImplementation):
         return None
 
 
+    def set_selected_item(self, selected_item):
+        """Function that replaces the currently selected item with a new item
+
+        Parameters
+        ----------
+        item : Object
+            A new selected item to replace the current one
+        """
+
+        if selected_item is not None and self.get() is not None:
+            self._view_items[self._selected_item] = selected_item
+
+
 class CheckBoxMenuImplementation(MenuImplementation):
     """Class representing checkbox menu ui implementation
 
