@@ -404,7 +404,7 @@ class ScrollMenu(Widget, py_cui.ui.MenuImplementation):
 
         Widget.__init__(self, id, title, grid, row, column, row_span, column_span, padx, pady, logger)
         py_cui.ui.MenuImplementation.__init__(self, logger)
-        self.set_help_text('Focus mode on ScrollMenu. Use up/down to scroll, Enter to trigger command, Esc to exit.')
+        self.set_help_text('Focus mode on ScrollMenu. Use Up/Down/PgUp/PgDown/Home/End to scroll, Esc to exit.')
 
 
     def _handle_mouse_press(self, x, y):
@@ -607,8 +607,7 @@ class Button(Widget):
         super()._handle_key_press(key_pressed)
         if key_pressed == py_cui.keys.KEY_ENTER:
             if self.command is not None:
-                ret = self.command()
-            return ret
+                return self.command()
 
 
     def _draw(self):
@@ -699,7 +698,8 @@ class TextBox(Widget, py_cui.ui.TextBoxImplementation):
             self._jump_to_start()
         elif key_pressed == py_cui.keys.KEY_END:
             self._jump_to_end()
-        elif key_pressed > 31 and key_pressed < 128:
+        elif key_pressed > 31 and key_pressed < 128 or \
+                key_pressed > 1000 and key_pressed < 1128:
             self._insert_char(key_pressed)
 
 
@@ -777,8 +777,8 @@ class ScrollTextBlock(Widget, py_cui.ui.TextBlockImplementation):
         if y >= self._cursor_max_up and y <= self._cursor_max_down:
             if x >= self._cursor_max_left and x <= self._cursor_max_right:
                 line_clicked_index = y - self._cursor_max_up + self._viewport_y_start
-                if len(self._text_lines) < line_clicked_index:
-                    self._cursor_text_pos_y = len(self._text_lines)
+                if len(self._text_lines) <= line_clicked_index:
+                    self._cursor_text_pos_y = len(self._text_lines) - 1
                     self._cursor_y = self._cursor_max_up + self._cursor_text_pos_y - self._viewport_y_start
                     line = self._text_lines[len(self._text_lines) - 1]
                 else:
